<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Űrlap szerkesztése címzettek");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Űrlap szerkesztése címzettek");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Form oldal");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Be lehet állítani egynél több fogadó elválasztva az e-maileket vesszővel.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Mentése címzett ...");
define('VIEW_FORM_TABLES_HEADING', "Táblázatok megtekintése");
define('VIEW_FORM_TABLES_BTN', "Táblázatok megtekintése");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Válassza ki a megtekinteni kívánt táblázatokat");
define('VIEW_FORM_TABLES_FILTER_READ', "Szűrő Olvasott üzenetek");
?>